@@ -16,6 +16,16 @@ ExperimentHub <-
              localHub=getExperimentHubOption("LOCAL"),
              ask=getExperimentHubOption("ASK"))
 {
+    if ((cache == R_user_dir("ExperimentHub", which="cache")) && (Sys.getenv("EXPERIMENT_HUB_CACHE")=="")){
+        olddefault = rappdirs::user_cache_dir(appname="ExperimentHub")
+        if (dir.exists(olddefault) && (length(list.files(olddefault)) != 0)){
+            stop(msg=paste0("DEFUNCT: As of ExperimentHub (>1.17.2), default caching location has changed.\n",
+                 "  Problematic cache: ", path.expand(olddefault), "\n",
+                 "  See https://bioconductor.org/packages/devel/bioc/vignettes/ExperimentHub/inst/doc/ExperimentHub.html#default-caching-location-update\n"))
+            cache = olddefault
+        }
+    }
+
     if (is.null(proxy)){
         connect <- suppressWarnings(tryCatch({
             readBin(hub, n=1L, what="raw")
